@@ -15,8 +15,9 @@ exports.read = function(params, cb) {
   }
 
   if (global.token) {
-    params = _.extend(params, {'token': global.token})
+    params = _.extend(params, {'token': global.token});
   }
+
   consul.kv.get(params, function(err, item) {
     if (err) return cb(err);
 
