@@ -228,13 +228,18 @@ Branch.prototype.init = function(cb) {
         if (err) {
           // If we have a failure on getCurrentRef, we suspect that the local copy is hosed.  Purge it
           // and start from scratch.
+          logger.error("Failed to get current ref due to %s", err);
+
           return this_obj.startFromScratch(null, cb, cb);
         }
 
         this_obj.pull(function(err) {
           // If we have a failure on pull, we suspect that the local copy is hosed.  Purge it
           // and start from scratch.
-          return this_obj.startFromScratch(null, cb, cb);
+          if (err) {
+            logger.error("Failed to get current ref due to %s", err);
+            return this_obj.startFromScratch(null, cb, cb);
+          }
 
           this_obj.busy = false;
           logger.info("Initialized branch %s from %s", this_obj.name, this_obj.repo_name);
