@@ -55,7 +55,7 @@ for (var i=2; i<process.argv.length; ++i) {
 
   if(process.argv[i] === '-f' || process.argv[i] === '--config-file') {
     if(i+1 >= process.argv.length) {
-      logger.error("No token provided with --config-file option");
+      logger.error("No file provided with --config-file option");
       process.exit(7);
     }
     global.config_file = process.argv[i+1];
@@ -65,74 +65,78 @@ for (var i=2; i<process.argv.length; ++i) {
 var config_reader = require('./config_reader.js');
 var config_seeder = require('./config_seeder.js');
 
+/**
+ * Read config from a specially named Consul resource.  If the config was not seeded
+ * (and this should be done using utils/config_seeder.js), git2consul will not boot.
+ */
+var read_config = function(){
+  config_reader.read({'key': global.config_key}, function(err, config) {
+
+    if (err) return console.error(err);
+
+    // Logging configuration is specified in the config object, so initialize our logger
+    // around that config.
+    logger.init(config);
+
+    if (global.token) {
+      // If a token was configured, register it with the consul broker
+      require('./consul').setToken(global.token);
+    }
+
+    var git = require('./git');
+
+    if (!config.repos || !config.repos.length > 0) {
+      // Fail startup.
+      logger.error("No repos found in configuration.  Halting.")
+      process.exit(1);
+    }
+
+    // Process command line switches, if any.  Command-line switches override the settings
+    // loaded from Consul.
+    for (var i=2; i<process.argv.length; ++i) {
+      if (process.argv[i] === '-n' || process.argv[i] === '--no_daemon') config['no_daemon'] = true;
+      if (process.argv[i] === '-h' || process.argv[i] === '--halt_on_change') config['halt_on_change'] = true;
+      else if (process.argv[i] === '-d' || process.argv[i] === '--local_store') {
+        if (i+1 >= process.argv[length]) {
+          logger.error("No dir provided with --local_store option");
+          process.exit(3);
+        }
+        config['local_store'] = process.argv[i+1];
+        ++i;
+      }
+    }
+
+    if (!config.local_store) {
+      config.local_store = os.tmpdir();
+    }
+
+    logger.info('git2consul is running');
+
+    process.on('uncaughtException', function(err) {
+      logger.error("Uncaught exception " + err);
+    });
+
+    // Set up git for each repo
+    git.createRepos(config, function(err) {
+      if (err) {
+        logger.error('Failed to create repos due to %s', err);
+        setTimeout(function() {
+          // If any git manager failed to start, consider this a fatal error.
+          process.exit(2);
+        }, 2000);
+      }
+    });
+  });
+};
+
 if (global.config_file) {
   config_seeder.set(global.config_key, global.config_file, function(err) {
     if (err) {
       logger.error(err)
       process.exit(2)
     };
+    read_config();
   });
+} else {
+  read_config();
 }
-
-/**
- * Read config from a specially named Consul resource.  If the config was not seeded
- * (and this should be done using utils/config_seeder.js), git2consul will not boot.
- */
-config_reader.read({'key': global.config_key}, function(err, config) {
-
-  if (err) return console.error(err);
-
-  // Logging configuration is specified in the config object, so initialize our logger
-  // around that config.
-  logger.init(config);
-
-  if (global.token) {
-    // If a token was configured, register it with the consul broker
-    require('./consul').setToken(global.token);
-  }
-
-  var git = require('./git');
-
-  if (!config.repos || !config.repos.length > 0) {
-    // Fail startup.
-    logger.error("No repos found in configuration.  Halting.")
-    process.exit(1);
-  }
-
-  // Process command line switches, if any.  Command-line switches override the settings
-  // loaded from Consul.
-  for (var i=2; i<process.argv.length; ++i) {
-    if (process.argv[i] === '-n' || process.argv[i] === '--no_daemon') config['no_daemon'] = true;
-    if (process.argv[i] === '-h' || process.argv[i] === '--halt_on_change') config['halt_on_change'] = true;
-    else if (process.argv[i] === '-d' || process.argv[i] === '--local_store') {
-      if (i+1 >= process.argv[length]) {
-        logger.error("No dir provided with --local_store option");
-        process.exit(3);
-      }
-      config['local_store'] = process.argv[i+1];
-      ++i;
-    }
-  }
-
-  if (!config.local_store) {
-    config.local_store = os.tmpdir();
-  }
-
-  logger.info('git2consul is running');
-
-  process.on('uncaughtException', function(err) {
-    logger.error("Uncaught exception " + err);
-  });
-
-  // Set up git for each repo
-  git.createRepos(config, function(err) {
-    if (err) {
-      logger.error('Failed to create repos due to %s', err);
-      setTimeout(function() {
-        // If any git manager failed to start, consider this a fatal error.
-        process.exit(2);
-      }, 2000);
-    }
-  });
-
-});
